cwlVersion: v1.2
class: Workflow
doc: >-
  The workflow starts with selecting Autophagy as the search term. Gene sets
  with set labels containing Autophagy were queried from Enrichr[1]. Identified
  matching terms from the MGI Mammalian Phenotype Level 4 2019[2] library were
  assembled into a collection of gene sets. A GMT was extracted from the Enrichr
  results for MGI_Mammalian_Phenotype_Level_4_2019. All the identified gene sets
  were combined using the union set operation. Reversers and mimickers from over
  1 million signatures were identified using SigCom LINCS[4]. Resolved drugs
  from the LINCS L1000 Chemical Perturbagens library. Identified matching terms
  from the KEGG 2021 Human[6] library were assembled into a collection of gene
  sets. A GMT was extracted from the Enrichr results for KEGG_2021_Human. All
  the identified gene sets were combined using the union set operation.
  Reversers and mimickers from over 1 million signatures were identified using
  SigCom LINCS[4]. Identified matching terms from the GO Biological Process
  2021[7] library were assembled into a collection of gene sets. A GMT was
  extracted from the Enrichr results for GO_Biological_Process_2021. All the
  identified gene sets were combined using the union set operation. Reversers
  and mimickers from over 1 million signatures were identified using SigCom
  LINCS[4]. Resolved drugs from the LINCS L1000 Chemical Perturbagens library.
  Resolved drugs from the LINCS L1000 Chemical Perturbagens library. The mean
  across multiple Scored Drugs is computed. The drugs were filtered by FDA
  Approved Drugs with the help of PubChem APIs[8]. 

  1. Xie, Z. et al. Gene Set Knowledge Discovery with Enrichr. Current Protocols
  vol. 1 (2021). doi:10.1002/cpz1.90

  2. Blake, J. A. et al. Mouse Genome Database (MGD): Knowledgebase for
  mouse–human comparative biology. Nucleic Acids Research vol. 49 D981–D987
  (2020). doi:10.1093/nar/gkaa1083

  4. Evangelista, J. E. et al. SigCom LINCS: data and metadata search engine for
  a million gene expression signatures. Nucleic Acids Research vol. 50 W697–W709
  (2022). doi:10.1093/nar/gkac328

  6. Kanehisa, M., Furumichi, M., Sato, Y., Kawashima, M. & Ishiguro-Watanabe,
  M. KEGG for taxonomy-based analysis of pathways and genomes. Nucleic Acids
  Research vol. 51 D587–D592 (2022). doi:10.1093/nar/gkac963

  7. Ashburner, M. et al. Gene Ontology: tool for the unification of biology.
  Nature Genetics vol. 25 25–29 (2000). doi:10.1038/75556

  8. Kim, S. et al. PubChem 2023 update. Nucleic Acids Research vol. 51
  D1373–D1380 (2022). doi:10.1093/nar/gkac956
requirements: {}
inputs:
  step-1-data:
    label: Pathway or Biological Process Input
    doc: Start with a Pathway or Biological Process
    type: File
outputs:
  step-1-output:
    label: Pathway or Biological Process
    doc: Pathway or Biological Process Term
    type: File
    outputSource: step-1/output
  step-2-output:
    label: Enrichr Term Search Results
    doc: Results of an Enrichr Term Search
    type: File
    outputSource: step-2/output
  step-3-output:
    label: Enrichr Phenotype Set
    doc: Set of Phenotypes
    type: File
    outputSource: step-3/output
  step-4-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-4/output
  step-5-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-5/output
  step-6-output:
    label: SigCom LINCS Gene Set Search Results
    doc: LINCS L1000 Gene Set Query Results
    type: File
    outputSource: step-6/output
  step-7-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-7/output
  step-8-output:
    label: Enrichr Pathway or Biological Process Set
    doc: Set of Pathway or Biological Processes
    type: File
    outputSource: step-8/output
  step-9-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-9/output
  step-10-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-10/output
  step-11-output:
    label: SigCom LINCS Gene Set Search Results
    doc: LINCS L1000 Gene Set Query Results
    type: File
    outputSource: step-11/output
  step-12-output:
    label: Enrichr Pathway or Biological Process Set
    doc: Set of Pathway or Biological Processes
    type: File
    outputSource: step-12/output
  step-13-output:
    label: Gene Matrix Transpose
    doc: Terms mapped to genes
    type: File
    outputSource: step-13/output
  step-14-output:
    label: Gene Set
    doc: Set of Genes
    type: File
    outputSource: step-14/output
  step-15-output:
    label: SigCom LINCS Gene Set Search Results
    doc: LINCS L1000 Gene Set Query Results
    type: File
    outputSource: step-15/output
  step-16-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-16/output
  step-17-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-17/output
  step-18-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-18/output
  step-19-output:
    label: Scored Drugs
    doc: ZScores of Drugs
    type: File
    outputSource: step-19/output
steps:
  step-1:
    run: Input[Pathway].cwl
    label: Pathway or Biological Process Input
    doc: Start with a Pathway or Biological Process
    in:
      data:
        source: step-1-data
      outputFilename:
        default: step-1-output.json
    out:
      - output
  step-2:
    run: EnrichrTermSearch[Pathway].cwl
    label: Extract Gene Sets Containing the Pathway or Biological Process in the Set
      Label
    doc: Find Pathway or Biological Process Terms in Enrichr Libraries
    in:
      inputs.term:
        label: Pathway or Biological Process
        source: step-1/output
      outputFilename:
        default: step-2-output.json
    out:
      - output
  step-3:
    run: ExtractEnrichrTermSearch[MGI_Mammalian_Phenotype_Level_4_2019].cwl
    label: Extract MGI Mammalian Phenotypes Associated with the Term Search
    doc: Extract Terms from the MGI Mammalian Phenotype Level 4 2019 Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-2/output
      outputFilename:
        default: step-3-output.json
    out:
      - output
  step-4:
    run: EnrichrSetTToGMT[Phenotype].cwl
    label: Enrichr Phenotype Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Phenotype Set
        source: step-3/output
      outputFilename:
        default: step-4-output.json
    out:
      - output
  step-5:
    run: GMTUnion.cwl
    label: Compute Union Gene Set
    doc: Find the union set of all genes in the GMT
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-4/output
      outputFilename:
        default: step-5-output.json
    out:
      - output
  step-6:
    run: SigComLINCSGeneSetSearch.cwl
    label: SigCom LINCS Gene Set Search
    doc: Query LINCS L1000 Signatures
    in:
      inputs.genes:
        label: Gene Set
        source: step-5/output
      outputFilename:
        default: step-6-output.json
    out:
      - output
  step-7:
    run: ExtractSigComLINCSGeneSetSearch[LINCS L1000 Chemical Perturbagens].cwl
    label: Extract LINCS L1000 Chemical Perturbagens
    doc: Extract signatures from the results
    in:
      inputs.searchResults:
        label: SigCom LINCS Gene Set Search Results
        source: step-6/output
      outputFilename:
        default: step-7-output.json
    out:
      - output
  step-8:
    run: ExtractEnrichrTermSearch[KEGG_2021_Human].cwl
    label: Extract KEGG Pathways Containing the Term Search
    doc: Extract Terms from the KEGG 2021 Human Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-2/output
      outputFilename:
        default: step-8-output.json
    out:
      - output
  step-9:
    run: EnrichrSetTToGMT[Pathway].cwl
    label: Enrichr Pathway or Biological Process Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Pathway or Biological Process Set
        source: step-8/output
      outputFilename:
        default: step-9-output.json
    out:
      - output
  step-10:
    run: GMTUnion.cwl
    label: Compute Union Gene Set
    doc: Find the union set of all genes in the GMT
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-9/output
      outputFilename:
        default: step-10-output.json
    out:
      - output
  step-11:
    run: SigComLINCSGeneSetSearch.cwl
    label: SigCom LINCS Gene Set Search
    doc: Query LINCS L1000 Signatures
    in:
      inputs.genes:
        label: Gene Set
        source: step-10/output
      outputFilename:
        default: step-11-output.json
    out:
      - output
  step-12:
    run: ExtractEnrichrTermSearch[GO_Biological_Process_2021].cwl
    label: Extract GO Biological Processes Containing the Term Search
    doc: Extract Terms from the GO Biological Process 2021 Library
    in:
      inputs.searchResults:
        label: Enrichr Term Search Results
        source: step-2/output
      outputFilename:
        default: step-12-output.json
    out:
      - output
  step-13:
    run: EnrichrSetTToGMT[Pathway].cwl
    label: Enrichr Pathway or Biological Process Set as GMT
    doc: Load Enrichr set as GMT
    in:
      inputs.enrichrset:
        label: Enrichr Pathway or Biological Process Set
        source: step-12/output
      outputFilename:
        default: step-13-output.json
    out:
      - output
  step-14:
    run: GMTUnion.cwl
    label: Compute Union Gene Set
    doc: Find the union set of all genes in the GMT
    in:
      inputs.gmt:
        label: Gene Matrix Transpose
        source: step-13/output
      outputFilename:
        default: step-14-output.json
    out:
      - output
  step-15:
    run: SigComLINCSGeneSetSearch.cwl
    label: SigCom LINCS Gene Set Search
    doc: Query LINCS L1000 Signatures
    in:
      inputs.genes:
        label: Gene Set
        source: step-14/output
      outputFilename:
        default: step-15-output.json
    out:
      - output
  step-16:
    run: ExtractSigComLINCSGeneSetSearch[LINCS L1000 Chemical Perturbagens].cwl
    label: Extract LINCS L1000 Chemical Perturbagens
    doc: Extract signatures from the results
    in:
      inputs.searchResults:
        label: SigCom LINCS Gene Set Search Results
        source: step-11/output
      outputFilename:
        default: step-16-output.json
    out:
      - output
  step-17:
    run: ExtractSigComLINCSGeneSetSearch[LINCS L1000 Chemical Perturbagens].cwl
    label: Extract LINCS L1000 Chemical Perturbagens
    doc: Extract signatures from the results
    in:
      inputs.searchResults:
        label: SigCom LINCS Gene Set Search Results
        source: step-15/output
      outputFilename:
        default: step-17-output.json
    out:
      - output
  step-18:
    run: MeanScoredT[Drug].cwl
    label: Mean Scored Values
    doc: Take the mean value across multiple scores
    in:
      inputs.scored:0:
        label: Scored Drugs
        source: step-7/output
      inputs.scored:1:
        label: Scored Drugs
        source: step-16/output
      inputs.scored:2:
        label: Scored Drugs
        source: step-17/output
      outputFilename:
        default: step-18-output.json
    out:
      - output
  step-19:
    run: FilterFDAApprovedDrugs[Scored[Drug]].cwl
    label: Extract FDA Approved Drugs
    doc: Filter the drugs with PubChem APIs
    in:
      inputs.drugs:
        label: Scored Drugs
        source: step-18/output
      outputFilename:
        default: step-19-output.json
    out:
      - output
